use axum::response::IntoResponse;
use axum::http::StatusCode;
use axum::Json;
use serde_json::json;
use thiserror::Error as thisError;

#[derive(thisError, Debug)]
pub enum Error {
    #[error("Invalid value provided: {0}")]
    ValueError(String)
}

pub type EmptyResult = Result<()>;
pub type Result<T> = std::result::Result<T, Error>;

impl IntoResponse for Error {
    fn into_response(self) -> axum::response::Response {
        let body = json!({"status": "error", "message": format!("{}", self)});

        (StatusCode::INTERNAL_SERVER_ERROR, Json(body)).into_response()
    }
}
